<?php

/**
 * @file
 * Contains \Drupal\system\Form\RssFeedsForm.
 */

namespace Drupal\social_stats\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\node\Entity\NodeType;
use Drupal\Core\Form\FormStateInterface;

class SocialStatsContentTypeForm extends ConfigFormBase {
  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'social_stats_content_type_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $node_types = NodeType::loadMultiple();
    $config_social_stats = $this->configFactory->get('social_stats.settings');

    // Loop over all the content types to build the config array per content-type.
    foreach ($node_types as $type) {
      $config = unserialize($config_social_stats->get('social_stats_content_types_' . $type->type));
      $form['social_stats'][$type->name] = array(
        '#type' => 'details',
        '#title' => $type->name,
        '#open' => TRUE,
      );
      $form['social_stats'][$type->name]['social_stats_' . $type->type] = array(
        '#type' => 'checkboxes',
        '#options' => array(
          'fb' => t('Facebook'),
          'twitter' => t('Twitter'),
          'gplus' => t('Google Plus'),
          'linkedin' => t('LinkedIn'),
        ),
        '#default_value' => unserialize($config_social_stats->get('social_stats_content_types_' . $type->type))
      );
    }
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $userInputValues = $form_state->getUserInput();
    $node_types = NodeType::loadMultiple();

    $config = $this->config('social_stats.settings');

    // Add new index to the config variable per content type.
    foreach ($node_types as $type) {
      $config->set('social_stats_content_types_' . $type->type, serialize($userInputValues['social_stats_' . $type->type]));
    }

    $config->save();
    drupal_set_message(t('Configuration saved successfully!'), 'status', FALSE);
    parent::submitForm($form, $form_state);
  }

}
